order_best: Uses brute-force enumeration to find the best hamiltonian on the complete graph on 1..n.
Description
Returns the best hamiltonian
Usage
order_best(d, maxexact=9,nsamples=50000,path_weight=sum,
cycle=FALSE,path_dir = path_cor,...)
Arguments
d
A dist, used to provide edge weights.
maxexact
If the sequence length is <= maxexact, find the overall best hamiltonian, otherwise compares nsamples
randomly generated permutations.
nsamples
If the sequence length is <= maxexact, finds the best of nsamples randomly generated permutations .
cycle
If TRUE, finds the shortest cycle, otherwise the shortest open path.
path_weight
Combines edge weights into a single path/cycle weight.
path_dir
If a function is provided, used to re-orient the cycle/path. Default function is path_cor.
Value
A vector containing a permutation of 1..n
Details
Requires package gtools.
Currently it is possible to find the best hamiltonian by complete enumeration for up to 10 nodes.
When path_dir is non NULL, the returned hamiltonian is also optimally oriented using best_orientation, which compares orientations via path_dir.
Examples
Run this code# NOT RUN {
require(PairViz)
order_best(eurodist)
# }
Run the code above in your browser using DataLab